---
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

title: Pebble SDK 2.0 BETA5 - Changelog
date: 2014-01-10
---

 * Pebble SDK 2.0 is currently in BETA and intended for developers only.
 * Applications written for Pebble 1.x are not compatible with SDK 2.0
 * If a 2.0 version of an application exists, the Pebble mobile applications will automatically install it when when a user upgrades her/his Pebble.

**You can start uploading your application to the Pebble appstore TODAY - [Please do so](http://dev-portal.getpebble.com/)!**

## What has changed since BETA4

Overview:

 - Fixed Android datalogging bugs where data would get duplicated
 - Merged datalogging fixes for iOS that were supposed to be in BETA4 (sorry)
 - Added an end of session message on Android datalogging
 - Fixed accelerometer bugs where the accelerometer would stop sending data
 - Changed the animation when switching from one watchface to the next ...
 - Changed the battery API to return values going up to 100%

### Known Problems and limitations

 * **Accelerometer locking up**: Although we have fixed several bugs around the accelerometer, we have noticed a few instance of the accelerometer locking up and the accel callback not being called anymore. If you see this happen again, please use the "Contact Support" button to send us logs. Make sure you change the subject to "Accelerometer lockup". Thank you very much!

 * `getAccountToken()` (in PebbleKit JS) is not working yet. It currently returns a random string. In an upcoming update (before 2.0) it will return a unique token linked to the Pebble user account.
 This is tied with appstore functionnalities and not available yet in this beta build.
 * Some crash due to internal timers and deadlock conditions are still being investigated.
 * This version will reset your persistent storage when you install it

### Changes for Firmware:

 - Added a script in the SDK to help analyze app memory usage (analyze_static_memory_usage)
 - Changed the animation between watchfaces
 - Fix various composition bugs during animations
 - Several fix to the Pebble filesystem to fix problems occuring in persistent storage and datalogging
 - Add `bitmap_layer_get_bitmap()`
 - s/1 minutes/1 minute/ in the alarm app
 - Do not crash when loading a font from a NULL resource (can happen when memory is tight!)
 - Ignore buttons while animating from one window to another
 - Fix the back button in the getting started
 - Fix simplicity to show the time immediately
 - Fix sliding text to animate the time in immediately
 - Change simplicity to load the fonts as system fonts
 - Invert modal window status bar icons
 - Reworked `gpath_draw_filled()` to use less memory and use heap instead of stack
 - Improve persistent storage behaviour under tight memory
 - Enforce file size limits
 - Improve number of sectors of the filesystem
 - Fix a bug where in some condition going up and down after installing a watchface would not return to it
 - Fix a bug where `text_layer_get_content_size()` could return values that caused the text to be truncated
 - Do not crash in `gpath_draw_filled()` if called with 0 points
 - Added event service unsubscribe for app_focus_event (fixes a crash for Glance and Upright)
 - Changed the battery API to return values going up to 100%

### Changes for Pebble iOS App:

 - Fixes to datalogging to avoid duplicated data and iOS app getting stuck

### Changes for Pebble Android App:

 - Added an intent sent when a data logging session is finished
 - Fix a problem where JavaScript would not start on android 4.0
 - Fix some bluetooth scanning bugs that could cause timeouts or pebbles not detected
 - Improved bluetooth pairing screens for various Android versions

### Changes for PebbleKit iOS:

 - Fix some threading/deadlock bugs

### Changes for PebbleKit Android:

 - Do not retransmit same datalogging blocks more than once
 - Add a callback when the datalogging session is finished

### Changes for SDK Tools:

 - Added command `pebble analyze-size` to dump sections and symbol sizes
 - Increase timeout of the wsclient (could be triggered when installing firmware)
 - Added `--simple` option to `pebble new-project` to create a minimalist app
 - Updated to websocket-client 1.12 and removed dependency to io_sock

### Changes for Examples:

 - Update classio-battery-connection example to peek() the bluetooth connection status at startup

### Changes for Documentation:

 - Updated JS configuration example
 - Added link to the pebble-hacks/configurable project in the JS doc
 - Removed reference to the 1Hz acc sampling rate (RIP)
 - Added an example use of the `pebble install` command in the example page
 - Updated the `app_focus_subscribe` documentation in the event guide
 - Added a note in the datalogging guide to mention it's not a realtime system
 - Added doc for `only_shown_on_communication` in the anatomy of a pebble app chapter
 - Added that you can call `app_message_outbox_begin` in `outbox_sent` and `outbox_failed` now
 - Fixed formatting of the appinfo.json example in the anatomy of a pebble app chapter
