---
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

title: Pebble SDK 2.0 DP3 - Changelog
date: 2013-10-21
---

This version brings some major improvements and a lot of bugfixes. In a nutshell, the big changes are:

 * PebbleKit JavaScript now supports geolocation on all platforms
 * Pebble supports the ANCS protocol. See details below.

This is a private release under NDA.

### Pebble and ANCS

Pebble has been working on integrating Bluetooth Low Energy (BLE) technology into our upcoming software releases.  The initial goal for this work is to greatly enhance the notification experience between a Pebble and a BLE-capable iOS7 device (the iPhone4S and later) - this leverages the "ANCS" notification feature of iOS7.  A requirement for the public release of BLE-capable Pebble SW is that it will not change the Android experience.  We will work on enhancing the BLE experience specifically for Android users in future SW releases.

If you wish to help Pebble test BLE and ANCS, please read this carefully, this is pre-release software and there are still areas of the experience we are actively enhancing.  We greatly appreciate your help in testing these important features :-)

Pebble SDK DP3 (and up) include BLEs capabilities. Download the firmware and mobile apps as instructed in the installation instructions. You do not need anything else.

To configure ANCS and BLE:

- If you already had email configured in the iOS Pebble app, go into the Pebble app and turn that OFF. With ANCS, email notifications will automatically mirror the notifications that show up on your phone.
- The first time you set this up (after you install BLE/ANCS firmware) you will need to pair your phone with the watch to make the BTLE connection.
    - On the watch, go into the "Settings" view, and select "Bluetooth".
    - On your iOS7 iPhone go into the "Settings" app, select "Bluetooth".
    - You should see an entry called "Pebble-LExxxx" where xxxx is the 4 digit code that is shown at the top of the Pebble's Bluetooth screen.  Select that entry, and confirm pairing.
- Ensure that BOTH traditional Bluetooth and BLE are paired.  You will not be able to perform all of the functions (such as handling phone calls) if the Bluetooth-Classic connection is not working.
- We are actively working on enhancements to pairing, so this process will change as we near public release.

Known issues:

- Only pairing from iOS BT Settings works for now. In-Pebble-app pairing is still TODO.
- If you have a red bar "Notifications require additional setup" in your iOS app, this will not disappear when LE is paired / ANCS is activated.  You can safely ignore it.
- Gmail/IMAP in Pebble app + ANCS = Duplicate emails.  We recommend turning off email accounts from the Pebble iOS app.
- "Forget" from the watch's BT settings menu doesn't work as expected. iDevice immediately reconnects again.
- All notifications have same icon
- Max message length is shorter than Bluetooth Classic.
- Impact on battery life: we are actively characterizing and working on this, but it is currently less than Bluetooth-Classic only.

Please report any bugs by email to: [ancsbug@getpebble.com](mailto:ancsbug@getpebble.com)!

**Remember, this release is under NDA. Please do not share word of this new feature. Thanks a lot!**

### Known problems and bugs

 * Data Logging still does not work on iOS7
 * On iOS, to try the "openURL()" function, you must first click the "Details Indicator" button on the table view that lists the JavaScript process
 * On Android, to upgrade an existing JavaScript app, you must first kill it in the "JS App Processes" view (look for the Skull And Bones button)
 * On some Android phones running 4.1, we have encountered a situation where location services were not working. This problem and the appropriate fix is described by Google [in this forum post](http://productforums.google.com/forum/#!msg/mobile/LEPcl9e3dYE/3LZEhiWACigJ).

### Pebble Firmware

 - Fix a bug where Pebble would keep vibrating after answering a call

### Pebble SDK

 - Fix a bug which caused all apps to share the same persistent storage file

### PebbleKit iOS/Android

 - Removed some deprecated/private APIs call from PebbleKit-iOS
 - Update PebbleKit-iOS project files to Xcode 5
 - Fix PebbleKit Android build - moved libraries to libs/

### PebbleKit JavaScript

 - Getting current location now works on iOS and Android. It is also possible to watch the current position and be notified when it changes.
 - Fixed a bug on iOS where sending multiple digits number would not work
 - Fixed a bug with the 2.1 release on Android where it would be impossible to use AppMessage (with PebbleKit JS)
 - Receiving byte arrays now also works on iOS
 - Added Pebble.getAccountToken() to get a unique token for the current user account (Note: this is not documented yet.)

### pebble tool

 - Do not return 0 if something bad happened
 - Display the footprint of the app in RAM and the available heap space

### Pebble iOS Application

 - Fixed a UI bug on iOS7 when deleting an app
 - Fixed the Developer Mode UI on iOS7

#### 2013 10 25 - 2.0-DP3.1

We have release a 3.1 update for the iOS application which should fix the most common crash for the app.

### Pebble Android application

 - Fixed a bug where the Android app would continuously try to connect to the Pebble even after disconnecting/unpairing
 - Fixed a bug where Facebook notifications would have duplicated content in the name field and the main field
 - Automatically start an app after installation
 - Fixed a bug where it would be impossible to skip the onboarding process
 - Fixed a bug where switching the device orientation during firmware upgrade would cause the upgrade to start again

### Pebble SDK Examples

 - Fixed a crash in dropzone
 - Improved the weatherjs example to use geolocation and display the name of the city
 - Added a very cool arcade game to demonstrate use of persistent storage (watchapps/pebble_arcade)

### Documentation

 - Simplified installation instructions for Linux
 - Fixed a lot of broken links
 - Added a chapter on iOS whitelisting
 - Added a chapter on fonts
 - Reworked most of the developer guides
