---
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

title: Pebble SDK 3.6 - Changelog
date: 2015-10-14
---

This changelog contains all changes since SDK 3.4. SDK 3.5 was never shipped.

### Known Issues

* Unfocused menu layer cells on Chalk may have their content inappropriately truncated.
  This behavior will improve before Pebble Time Round is released.

### Changes to Firmware

* Added support for [circular watches](/round/).
* Window stack animations were disabled on Chalk.
* Adjusted the display of [`ActionBarLayers`](``ActionBarLayer``) for circular watches.
* Adjusted the display of [`ActionMenus`](``ActionMenu``) for circular watches.
* Increased the height of the ``StatusBarLayer`` on Chalk (16 to 24 pixels).
* Improved backlight behavior when dictating text.
* Added support for 8 KiB AppMessage buffers.

### Changes to SDK

* Added the new "Chalk" platform for the Pebble Time Round.
* Added the [Dictation API](/guides/pebble-apps/sensors/dictation/), enabling voice input on
  the Basalt and Chalk platforms.
* Added `PBL_ROUND`, `PBL_RECT` and `PBL_PLATFORM_CHALK` defines.
* Added ``PBL_IF_ROUND_ELSE``, ``PBL_IF_RECT_ELSE``, ``PBL_IF_COLOR_ELSE`` and
  ``PBL_IF_BW_ELSE`` macros. ``COLOR_FALLBACK`` is now considered deprecated.
* Added ``graphics_fill_radial`` and ``graphics_draw_arc``, for drawing partial circles.
* Added ``gpoint_from_polar`` and ``grect_centered_from_polar`` for conversion from
  polar to cartesian coordinates.
* Added ``ContentIndicator``, which provides a visual indicator of content above or
  below the display.
* Added ``menu_layer_set_center_focused``, which forces the highlighted menu item to always
  be in the center of the display. This is the default configuration for menus on Chalk.
* Added ``menu_layer_is_index_selected``.
* Added constants for the heights of menu cells on Chalk: ``MENU_CELL_ROUND_FOCUSED_SHORT_CELL_HEIGHT``,
  ``MENU_CELL_ROUND_FOCUSED_TALL_CELL_HEIGHT``, ``MENU_CELL_ROUND_UNFOCUSED_SHORT_CELL_HEIGHT`` and
  ``MENU_CELL_ROUND_UNFOCUSED_TALL_CELL_HEIGHT``.
* Added ``DEG_TO_TRIGANGLE``, the inverse of the pre-existing ``TRIGANGLE_TO_DEG``.
* Added ``GBitmapFormat8BitCircular``, the new framebuffer format used on Chalk.
* Added ``gbitmap_get_data_row_info``, because ``GBitmapFormat8BitCircular`` does not have
  a constant number of bytes per row. This should now be used for all framebuffer
  manipulation.
* Added the ``GTextAttributes`` structure, with methods for defining text flow and paging on a
  circular display.
* Added support for ``GTextAttributes`` to ``graphics_draw_text``. That `NULL` parameter that
  you've been tacking on the end for two and a half years now actually does something.
* Added methods to ``TextLayer`` for flowing and paging text on a circular display.
* Added paging support to ``ScrollLayer``.


### Changes to Pebble Tool

* Added support for Chalk and circular displays.
* Added the [`pebble transcribe` command](/guides/tools-and-resources/pebble-tool/),
  enabling testing dictation in the emulator.
* Added the [`pebble data-logging` command](/guides/tools-and-resources/pebble-tool/),
  to download stored datalogging from the watch to the computer.
* Added the [`pebble emu-time-format` commmand](/guides/tools-and-resources/pebble-tool/),
  allowing switching of the emulator between 12-hour and 24-hour formats.


### Changes to Emulator/Phonesim

* Added support for Chalk and circular displays.
* Fixed a JavaScript runtime crash when sending non-ASCII characters by AppMessage.
