---
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


layout: more/markdown
title: App Inspiration
menu_subsection: inspiration
permalink: /inspiration/
generate_toc: true
page_class: inspiration-page
---

We're often asked by developers at hackathons and code days what kinds of apps 
they should write for Pebble. It’s a great question and in an attempt to begin 
answering it, we decided to publish a list of ideas and use cases that we would 
love to see our developers tackling. 

We hope that this list provides you with ideas, inspiration, and a 
glimpse into what we hope to see more of in the future. If you have 
any suggestions for ideas or categories we should add to this list, 
please fill out 
[this form](https://docs.google.com/forms/d/1S6_C4JP5HREK9jAolDXjOepEI1mkZpTTBm_GK6XIzg4/viewform)
and let us know what you think! 

If you want to show us what you're working on, [reach out to us](/contact). We'd 
love to provide feedback, connect developers to each other, showcase cool 
apps in our developer newsletter, and even sponsor some amazing projects. 

## Transportation

> When you’re on the move, the last thing you want to do is take out your phone.

We think about this in two categories: Navigation & Public Transit

### Navigation

Knowing when to take that left turn usually only requires a few well 
timed glances. How can Pebble help you get from point A to point B in a way 
that’s simple and efficient? 

### Transit

Our Pebblers in the SF Bay Area rave about the 
[Caltrain app](http://apps.getpebble.com/en_US/application/53eb5caf6743f7a863000201), 
which gives us the closest Caltrain station, time until the next train, 
and future train schedules. It has simplified our morning commute 
dramatically and lets us keep our phones in our pockets at the right time. 
How awesome would it be if Pebblers all over the world were able to have 
that same luxury? Can we incorporate the Pebble timeline into that experience?

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28486/transportation-apps#latest)

## Workout Companions

> A personal trainer on your wrist

When you’re at the gym, it’s a pain to constantly pull out your phone 
to figure out which exercise comes next, track your reps and time, and log 
what you did. There are some great timers, stopwatches, running & biking 
trackers, and rep counters out there, but we haven’t yet seen the whole 
package come together. 

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28487/workout-companions#latest)

## Gift Cards, Loyalty, Ticketing

> Get rid of all those extra cards, apps, and keychains</p>

Aren’t you tired of carrying around a giant wallet or keeping track of 
a bunch of paper tickets? As the device that’s always on you (and always on), 
Pebble has the potential to replace all that clutter. How cool would it be 
to walk into your favorite retailer, concert, sports game, pharmacy, or 
gas station and have to do nothing but flash your magic wrist-wand? Pretty 
cool. 

Working with [Eventbrite](https://apps.getpebble.com/applications/55b7e74d180264f33f00007e)
made a lot of sense - get events on your Pebble timeline and launch your tickets 
right from your wrist. How can we get everyone’s tickets and cards onto 
their wrists?

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28498/gift-cards-loyalty-cards-and-ticketing#latest)

## Local Discovery

> What's happening in your city tonight?

Timeline is a great place to see your own events, but what about the 
ones you have yet to discover? Imagine all the coolest events in your area 
landing right on your timeline. We love using services like Eventbrite, 
Meetup, Songkick, and Bandsintown to discover what’s going on near us — 
how can we bring this to Pebble?

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28488/local-discovery#latest)

## Pebble to Pebble Communication

> Communicate with other Pebblers without taking out your phone

Simply put - Pebblers are awesome, and awesome people should stick 
together. How cool would it be if you could communicate with other 
Pebblers without even needing a phone? 
[Boopy](https://apps.getpebble.com/applications/556211d49853b8c3f30000b9)
is an awesome start - how far can we take this?

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28489/watch-to-watch-communication#latest)

## Tasks, Reminders, Todo Lists

> Pebblers are busy people who get stuff done

With timeline as a core experience on the Pebble Time and the Voice API 
coming soon, we’re excited to see how developers can make Pebble the 
ultimate tool for productivity.

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28490/tasks-reminders-to-dos#latest)

## Addictive Games

> Ever played [Pixel Miner](https://apps.getpebble.com/applications/539e18f21a19dec6ca0000aa)? 
  That’s one we can never put down….

Whether it’s about trivia, flapping birds, or paper planes, we’d love 
to see more games in the appstore that endlessly entertain Pebblers and 
keep them coming back for more. 

And don’t forget, you’ve got a few tricks up your sleeve to keep them 
coming back… (e.g. [timeline pins](/guides/pebble-timeline/), the
[Wakeup API](/guides/events-and-services/wakeups/)).

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28491/addictive-games#latest)

## Home

> Forget those remotes, switches, keys, and outlets — control and monitor your home with your watch

Studies show over 80% of Americans have at some point in their life 
misplaced one of the above. With more of your home getting smarter and 
more connected, Pebble can become the primary controller and monitor for everything. 
[Leaf](https://apps.getpebble.com/applications/52ccd42551a80d792600002c) 
is an awesome example -- let’s keep it going.

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28492/pebble-for-the-home#latest)

## Security

> Pebble unlocks what matters

[Authenticator](https://apps.getpebble.com/applications/52f1a4c3c4117252f9000bb8)
has shown us the power of Pebble for easy two factor authentication. Whether 
it’s for physical or digital spaces, a watch that’s always on you is the perfect 
tool to keep what matters safe. Let’s see what else Pebble can unlock...

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28493/pebble-for-security#latest)

## Enterprise

> Businesses can't ignore wearables either...

Wearables provide a new, meaningful way for consumers to interface with 
services, retailers, and brands. At the same time, employees and managers 
have a newfound ability to notify, organize, coordinate, and learn from 
one another. The grass is green and the sky’s the limit. 

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28494/pebble-for-businesses#latest)       

## On Demand

> Making 'on-demand' even faster
    
People expect food, rides, dates, and just about anything else faster 
and on-demand. Pebble is always with you, always on, and always a button 
click away from something awesome. 

Let’s give Pebble a few more superpowers…

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28495/pebble-for-on-demand#latest)

## Stay in the Know

> Pebblers want to stay on top of what's happening

The watch is a great place to consume little bits of information. News, 
political events, music releases, entertainment, or anything else that 
matters - we’d love to see how Pebble can help.

Let’s keep people in the know about what’s happening in the world, 
wherever they are. 

Maybe you even want to find ways to time-travel into 
the future? We’re listening. 

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28496/pebble-and-staying-in-the-know#latest)

## Time

> Pebble at its core is a damn good watch

Time is the essence of everything we do here at Pebble. We’ve seen all 
sorts of awesome watchfaces -- dynamic, digital, analog, weather... but 
there’s always more that can be done. If you can think up and create new, 
innovative ways to tell time, we’re interested.

[Join the Discussion >{more}](https://forums.getpebble.com/discussion/28497/time#latest)

---

Anything pique your interest? We certainly hope so! Fire up your 
emulators, get building, and let’s **#makeawesomehappen** together.

Don't forget, we have some pretty cool 
[design and interaction guides](/guides/design-and-interaction/)
to help you out.

Off you go!
